<h6 align="left">
    <img src="https://cdnquakingaspen.s3.eu-central-1.amazonaws.com/quaking+aspen+logo+teal+full-02.png"  />
</h6>

# aws-s3-resource
[Introduction](#Introduction)\
[Getting Started](#Started)\
[Example](#Example)\
[Contributors](#Contributors)\
[License](#License)

<h2 id="Introduction">Introduction</h2>
This library is to ease the operations done on AWS S3 buckets and objects
 
<h2 id="Started">Getting Started</h2>
In order to install,open the command prompt and type ✌️:
  
```
pip install aws_s3_resource
```
<h2 id="Example">Example</h2>

In order to use refer to the following [example](https://github.com/Quakingaspen-codehub/aws_s3_resource/blob/master/Example/aws_example.ipynb)
<h2 id="">Contributors</h2>

This project exists thanks to all the people who contribute. [[Contribute](CONTRIBUTING.md)].
<a href="https://github.com/Quakingaspen-codehub/aws_s3_resource/graphs/contributors">
""
</a>

<h2 id="License">License</h2>


This library is licensed under the MIT License - see the [LICENSE.md](LICENSE) file for details.
